pub enum MetadataExpire {
Duration(u64),
Never,
}Expand description
How long metadata is considered valid before a refresh is required.
Can be a specific duration in seconds, or Never to disable expiration.
Examples
use dnf_repofile::MetadataExpire;
let expire = MetadataExpire::Duration(3600); // 1 hour
let never = MetadataExpire::Never;Variants